California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 069 - REQUIRES THAT CERTAIN NEW TRANSPORTATION REVENUES BE USED FOR TRANSPORTATION PURPOSES. LEGISLATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400937 | NO ON PROP 6: STOP THE ATTACK ON BRIDGE & ROAD SAFETY, SPONSORED BY BUSINESS, LABOR, LOCAL GOVERNMENTS AND TRANSPORTATION ADVOCATES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1404245 | COUNTY SUPERVISORS ASSOCIATION OF CALIFORNIA DBA CALIFORNIA STATE ASSOCIATION OF COUNTIES (NONPROFIT 501(C)(4)) | SUPPORT